@@ -19,11 +19,13 @@ done
 [ -d "./dist" ] && rm -rf ./dist
 
 # Remove launcher scripts
-filenames=("/usr/bin/nwg-displays")
+filenames=("/usr/bin/nwg-displays" "/usr/bin/nwg-displays-apply" "/usr/bin/nwg-displays-toggle-wallpapers")
 
 for filename in "${filenames[@]}"; do
-  rm -f "$filename"
-  echo "Removing -f $filename"
+  if [ -f "$filename" ]; then
+      rm -f "$filename"
+      echo "Removing -f $filename"
+  fi
 done
 
 python -m build --wheel --no-isolation
@@ -34,4 +36,4 @@ install -Dm 644 -t "/usr/share/applications" "$PROGRAM_NAME.desktop"
 install -Dm 644 -t "/usr/share/pixmaps" "$PROGRAM_NAME.svg"
 
 install -Dm 644 -t "/usr/share/licenses/$PROGRAM_NAME" LICENSE
-install -Dm 644 -t "/usr/share/doc/$PROGRAM_NAME" README.md
+install -Dm 644 -t "/usr/share/doc/$PROGRAM_NAME" README.md
\ No newline at end of file
